@@ -103,11 +103,13 @@ const struct option stress_long_options[] = {
 	{ "cache-level",	1,	0,	OPT_cache_level },
 	{ "cache-no-affinity",	0,	0,	OPT_cache_no_affinity },
 	{ "cache-ops",		1,	0,	OPT_cache_ops },
+	{ "cache-permute",	0,	0,	OPT_cache_permute },
 	{ "cache-prefetch",	0,	0,	OPT_cache_prefetch },
 	{ "cache-prefetchw",	0,	0,	OPT_cache_prefetchw },
 	{ "cache-sfence",	0,	0,	OPT_cache_sfence },
 	{ "cache-ways",		1,	0,	OPT_cache_ways },
 	{ "cachehammer",	1,	0,	OPT_cachehammer },
+	{ "cachehammer-numa",	0,	0,	OPT_cachehammer_numa },
 	{ "cachehammer-ops",	1,	0,	OPT_cachehammer_ops },
 	{ "cacheline",		1,	0, 	OPT_cacheline },
 	{ "cacheline-affinity",	0,	0,	OPT_cacheline_affinity },
@@ -115,6 +117,8 @@ const struct option stress_long_options[] = {
 	{ "cacheline-ops",	1,	0,	OPT_cacheline_ops },
 	{ "cap",		1,	0, 	OPT_cap },
 	{ "cap-ops",		1,	0, 	OPT_cap_ops },
+	{ "cgroup",		1,	0,	OPT_cgroup },
+	{ "cgroup-ops",		1,	0,	OPT_cgroup_ops },
 	{ "chattr",		1,	0, 	OPT_chattr },
 	{ "chattr-ops",		1,	0,	OPT_chattr_ops },
 	{ "change-cpu",		0,	0,	OPT_change_cpu },
@@ -127,8 +131,9 @@ const struct option stress_long_options[] = {
 	{ "chown-ops",		1,	0,	OPT_chown_ops },
 	{ "chroot",		1,	0, 	OPT_chroot},
 	{ "chroot-ops",		1,	0,	OPT_chroot_ops },
-	{ "cgroup",		1,	0,	OPT_cgroup },
-	{ "cgroup-ops",		1,	0,	OPT_cgroup_ops },
+	{ "chyperbolic",	1,	0,	OPT_chyperbolic },
+	{ "chyperbolic-method",	1,	0,	OPT_chyperbolic_method },
+	{ "chyperbolic-ops",	1,	0,	OPT_chyperbolic_ops },
 	{ "class",		1,	0,	OPT_class },
 	{ "clock",		1,	0,	OPT_clock },
 	{ "clock-ops",		1,	0,	OPT_clock_ops },
@@ -157,6 +162,9 @@ const struct option stress_long_options[] = {
 	{ "crypt",		1,	0,	OPT_crypt },
 	{ "crypt-method",	1,	0,	OPT_crypt_method },
 	{ "crypt-ops",		1,	0,	OPT_crypt_ops },
+	{ "ctrig",		1,	0,	OPT_ctrig },
+	{ "ctrig-method",	1,	0,	OPT_ctrig_method },
+	{ "ctrig-ops",		1,	0,	OPT_ctrig_ops },
 	{ "cyclic",		1,	0,	OPT_cyclic },
 	{ "cyclic-dist",	1,	0,	OPT_cyclic_dist },
 	{ "cyclic-method",	1,	0,	OPT_cyclic_method },
@@ -251,11 +259,14 @@ const struct option stress_long_options[] = {
 	{ "far-branch",		1,	0,	OPT_far_branch },
 	{ "far-branch-flush",	0,	0,	OPT_far_branch_flush },
 	{ "far-branch-ops",	1,	0,	OPT_far_branch_ops },
+	{ "far-branch-pageout",	0,	0,	OPT_far_branch_pageout },
 	{ "far-branch-pages",	1,	0,	OPT_far_branch_pages },
 	{ "fault",		1,	0,	OPT_fault },
 	{ "fault-ops",		1,	0,	OPT_fault_ops },
 	{ "fcntl",		1,	0,	OPT_fcntl},
 	{ "fcntl-ops",		1,	0,	OPT_fcntl_ops },
+	{ "fd-abuse",		1,	0,	OPT_fd_abuse },
+	{ "fd-abuse-ops",	1,	0,	OPT_fd_abuse_ops },
 	{ "fd-fork",		1,	0,	OPT_fd_fork },
 	{ "fd-fork-fds",	1,	0,	OPT_fd_fork_fds },
 	{ "fd-fork-file",	1,	0,	OPT_fd_fork_file },
@@ -407,6 +418,7 @@ const struct option stress_long_options[] = {
 	{ "ioport",		1,	0,	OPT_ioport },
 	{ "ioport-ops",		1,	0,	OPT_ioport_ops },
 	{ "ioport-opts",	1,	0,	OPT_ioport_opts },
+	{ "ioport-port",	1,	0,	OPT_ioport_port },
 	{ "ioprio",		1,	0,	OPT_ioprio },
 	{ "ioprio-ops",		1,	0,	OPT_ioprio_ops },
 	{ "iostat",		1,	0,	OPT_iostat },
@@ -462,6 +474,9 @@ const struct option stress_long_options[] = {
 	{ "lease",		1,	0,	OPT_lease },
 	{ "lease-breakers",	1,	0,	OPT_lease_breakers },
 	{ "lease-ops",		1,	0,	OPT_lease_ops },
+	{ "limit-as",		1,	0,	OPT_limit_as },
+	{ "limit-data",		1,	0,	OPT_limit_data },
+	{ "limit-stack",	1,	0,	OPT_limit_stack },
 	{ "link",		1,	0,	OPT_link },
 	{ "link-ops",		1,	0,	OPT_link_ops },
 	{ "link-sync",		0,	0,	OPT_link_sync },
@@ -474,6 +489,7 @@ const struct option stress_long_options[] = {
 	{ "llc-affinity-mlock",	0,	0,	OPT_llc_affinity_mlock },
 	{ "llc-affinity-numa",	0,	0,	OPT_llc_affinity_numa },
 	{ "llc-affinity-ops",	1,	0,	OPT_llc_affinity_ops },
+	{ "llc-affinity-size",	1,	0,	OPT_llc_affinity_size },
 	{ "loadavg",		1,	0,	OPT_loadavg },
 	{ "loadavg-ops",	1,	0,	OPT_loadavg_ops },
 	{ "loadavg-max",	1,	0,	OPT_loadavg_max },
@@ -606,6 +622,12 @@ const struct option stress_long_options[] = {
 	{ "mmapaddr",		1,	0,	OPT_mmapaddr },
 	{ "mmapaddr-mlock",	0,	0,	OPT_mmapaddr_mlock },
 	{ "mmapaddr-ops",	1,	0,	OPT_mmapaddr_ops },
+	{ "mmapcow",		1,	0,	OPT_mmapcow },
+	{ "mmapcow-fork",	0,	0,	OPT_mmapcow_fork },
+	{ "mmapcow-free",	0,	0,	OPT_mmapcow_free },
+	{ "mmapcow-mlock",	0,	0,	OPT_mmapcow_mlock },
+	{ "mmapcow-numa",	0,	0,	OPT_mmapcow_numa },
+	{ "mmapcow-ops",	1,	0,	OPT_mmapcow_ops },
 	{ "mmapfiles",		1,	0,	OPT_mmapfiles },
 	{ "mmapfiles-numa",	0,	0,	OPT_mmapfiles_numa },
 	{ "mmapfiles-ops",	1,	0,	OPT_mmapfiles_ops },
@@ -628,6 +650,11 @@ const struct option stress_long_options[] = {
 	{ "mmapmany-mlock",	0,	0,	OPT_mmapmany_mlock },
 	{ "mmapmany-numa",	0,	0,	OPT_mmapmany_numa },
 	{ "mmapmany-ops",	1,	0,	OPT_mmapmany_ops },
+	{ "mmaprandom",		1,	0,	OPT_mmaprandom },
+	{ "mmaprandom-ops",	1,	0,	OPT_mmaprandom_ops },
+	{ "mmaprandom-mappings",1,	0,	OPT_mmaprandom_mappings },
+	{ "mmaprandom-maxpages",1,	0,	OPT_mmaprandom_maxpages },
+	{ "mmaprandom-numa",	0,	0,	OPT_mmaprandom_numa },
 	{ "mmaptorture",	1,	0,	OPT_mmaptorture },
 	{ "mmaptorture-bytes",	1,	0,	OPT_mmaptorture_bytes },
 	{ "mmaptorture-msync",	1,	0,	OPT_mmaptorture_msync },
@@ -1038,8 +1065,10 @@ const struct option stress_long_options[] = {
 	{ "spawn-ops",		1,	0,	OPT_spawn_ops },
 	{ "spinmem",		1,	0,	OPT_spinmem },
 	{ "spinmem-affinity",	0,	0,	OPT_spinmem_affinity },
-	{ "spinmem-ops",	1,	0,	OPT_spinmem_ops },
 	{ "spinmem-method",	1,	0,	OPT_spinmem_method },
+	{ "spinmem-numa",	0,	0,	OPT_spinmem_numa },
+	{ "spinmem-ops",	1,	0,	OPT_spinmem_ops },
+	{ "spinmem-yield",	0,	0,	OPT_spinmem_yield },
 	{ "splice",		1,	0,	OPT_splice },
 	{ "splice-bytes",	1,	0,	OPT_splice_bytes },
 	{ "splice-ops",		1,	0,	OPT_splice_ops },
@@ -1065,6 +1094,7 @@ const struct option stress_long_options[] = {
 	{ "stream-madvise",	1,	0,	OPT_stream_madvise },
 	{ "stream-mlock",	0,	0,	OPT_stream_mlock },
 	{ "stream-ops",		1,	0,	OPT_stream_ops },
+	{ "stream-prefetch",	0,	0,	OPT_stream_prefetch },
 	{ "stressor-time",	0,	0,	OPT_stressor_time },
 	{ "stressors",		0,	0,	OPT_stressors },
 	{ "swap",		1,	0,	OPT_swap },
@@ -1211,6 +1241,7 @@ const struct option stress_long_options[] = {
 	{ "vforkmany-vm-bytes", 1,	0,	OPT_vforkmany_vm_bytes },
 	{ "vm",			1,	0,	OPT_vm },
 	{ "vm-bytes",		1,	0,	OPT_vm_bytes },
+	{ "vm-flush",		0,	0,	OPT_vm_flush },
 	{ "vm-hang",		1,	0,	OPT_vm_hang },
 	{ "vm-keep",		0,	0,	OPT_vm_keep },
 #if defined(MAP_LOCKED)
