@@ -252,11 +252,13 @@ typedef enum {
 	OPT_cache_level,
 	OPT_cache_sfence,
 	OPT_cache_no_affinity,
+	OPT_cache_permute,
 	OPT_cache_prefetch,
 	OPT_cache_prefetchw,
 	OPT_cache_ways,
 
 	OPT_cachehammer,
+	OPT_cachehammer_numa,
 	OPT_cachehammer_ops,
 
 	OPT_cacheline,
@@ -288,6 +290,10 @@ typedef enum {
 	OPT_chroot,
 	OPT_chroot_ops,
 
+	OPT_chyperbolic,
+	OPT_chyperbolic_method,
+	OPT_chyperbolic_ops,
+
 	OPT_clock,
 	OPT_clock_ops,
 
@@ -324,6 +330,10 @@ typedef enum {
 	OPT_crypt_method,
 	OPT_crypt_ops,
 
+	OPT_ctrig,
+	OPT_ctrig_method,
+	OPT_ctrig_ops,
+
 	OPT_cyclic,
 	OPT_cyclic_ops,
 	OPT_cyclic_dist,
@@ -441,6 +451,7 @@ typedef enum {
 	OPT_far_branch,
 	OPT_far_branch_flush,
 	OPT_far_branch_ops,
+	OPT_far_branch_pageout,
 	OPT_far_branch_pages,
 
 	OPT_fault,
@@ -449,6 +460,9 @@ typedef enum {
 	OPT_fcntl,
 	OPT_fcntl_ops,
 
+	OPT_fd_abuse,
+	OPT_fd_abuse_ops,
+
 	OPT_fd_fork,
 	OPT_fd_fork_fds,
 	OPT_fd_fork_file,
@@ -640,6 +654,7 @@ typedef enum {
 	OPT_ioport,
 	OPT_ioport_ops,
 	OPT_ioport_opts,
+	OPT_ioport_port,
 
 	OPT_ionice_class,
 	OPT_ionice_level,
@@ -716,6 +731,10 @@ typedef enum {
 	OPT_led,
 	OPT_led_ops,
 
+	OPT_limit_as,
+	OPT_limit_data,
+	OPT_limit_stack,
+
 	OPT_link,
 	OPT_link_ops,
 	OPT_link_sync,
@@ -730,6 +749,7 @@ typedef enum {
 	OPT_llc_affinity_mlock,
 	OPT_llc_affinity_numa,
 	OPT_llc_affinity_ops,
+	OPT_llc_affinity_size,
 
 	OPT_loadavg,
 	OPT_loadavg_ops,
@@ -899,6 +919,13 @@ typedef enum {
 	OPT_mmapaddr_mlock,
 	OPT_mmapaddr_ops,
 
+	OPT_mmapcow,
+	OPT_mmapcow_fork,
+	OPT_mmapcow_free,
+	OPT_mmapcow_mlock,
+	OPT_mmapcow_numa,
+	OPT_mmapcow_ops,
+
 	OPT_mmapfiles,
 	OPT_mmapfiles_numa,
 	OPT_mmapfiles_ops,
@@ -926,6 +953,12 @@ typedef enum {
 	OPT_mmapmany_numa,
 	OPT_mmapmany_ops,
 
+	OPT_mmaprandom,
+	OPT_mmaprandom_ops,
+	OPT_mmaprandom_mappings,
+	OPT_mmaprandom_maxpages,
+	OPT_mmaprandom_numa,
+
 	OPT_mmaptorture,
 	OPT_mmaptorture_bytes,
 	OPT_mmaptorture_msync,
@@ -1473,8 +1506,10 @@ typedef enum {
 
 	OPT_spinmem,
 	OPT_spinmem_affinity,
-	OPT_spinmem_ops,
 	OPT_spinmem_method,
+	OPT_spinmem_numa,
+	OPT_spinmem_ops,
+	OPT_spinmem_yield,
 
 	OPT_splice,
 	OPT_splice_ops,
@@ -1508,6 +1543,7 @@ typedef enum {
 	OPT_stream_madvise,
 	OPT_stream_mlock,
 	OPT_stream_ops,
+	OPT_stream_prefetch,
 
 	OPT_stressor_time,
 
@@ -1693,6 +1729,7 @@ typedef enum {
 	OPT_vforkmany_vm_bytes,
 
 	OPT_vm_bytes,
+	OPT_vm_flush,
 	OPT_vm_hang,
 	OPT_vm_keep,
 	OPT_vm_populate,
