@@ -168,7 +168,12 @@ size_t stress_resources_allocate(
 	const pid_t ppid = getppid();
 #endif
 	const size_t page_size = args->page_size;
-	static const int domains[] = { AF_INET, AF_INET6 };
+	static const int domains[] = {
+		AF_INET,
+#if defined(AF_INET6)
+		AF_INET6,
+#endif
+	};
 	static const int types[] = { SOCK_STREAM, SOCK_DGRAM };
 
 	stress_resources_init(resources, num_resources);
@@ -341,7 +346,7 @@ size_t stress_resources_allocate(
 				const size_t locked = STRESS_MINIMUM(mlock_size, resources[i].m_mmap_size);
 
 				stress_set_vma_anon_name(resources[i].m_mmap, resources[i].m_mmap_size, "resources-mmap");
-				(void)stress_madvise_random(resources[i].m_mmap, resources[i].m_mmap_size);
+				(void)stress_madvise_randomize(resources[i].m_mmap, resources[i].m_mmap_size);
 				(void)stress_mincore_touch_pages_interruptible(resources[i].m_mmap, resources[i].m_mmap_size);
 				if (locked > 0) {
 					shim_mlock(resources[i].m_mmap, locked);
@@ -706,7 +711,7 @@ void stress_resources_free(
 		}
 		if (resources[i].m_mmap && (resources[i].m_mmap != MAP_FAILED)) {
 			(void)shim_munlock(resources[i].m_mmap, resources[i].m_mmap_size);
-			(void)stress_munmap_retry_enomem(resources[i].m_mmap, resources[i].m_mmap_size);
+			(void)stress_munmap_force(resources[i].m_mmap, resources[i].m_mmap_size);
 			resources[i].m_mmap = MAP_FAILED;
 		}
 		if (resources[i].pipe_ret != -1) {
@@ -731,7 +736,7 @@ void stress_resources_free(
 			resources[i].fd_memfd = -1;
 		}
 		if (resources[i].ptr_memfd) {
-			(void)stress_munmap_retry_enomem(resources[i].ptr_memfd, page_size);
+			(void)stress_munmap_force(resources[i].ptr_memfd, page_size);
 			resources[i].ptr_memfd = MAP_FAILED;
 		}
 #endif
@@ -741,7 +746,7 @@ void stress_resources_free(
 			resources[i].fd_memfd_secret = -1;
 		}
 		if (resources[i].ptr_memfd_secret) {
-			(void)stress_munmap_retry_enomem(resources[i].ptr_memfd_secret, page_size);
+			(void)stress_munmap_force(resources[i].ptr_memfd_secret, page_size);
 			resources[i].ptr_memfd_secret = NULL;
 		}
 #endif
