@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C)      2022 Colin Ian King.
+ * Copyright (C) 2022-2025 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,7 @@
  *
  */
 #include "stress-ng.h"
+#include "core-builtin.h"
 #include "core-capabilities.h"
 
 #if defined(HAVE_LINUX_ANDROID_BINDER_H)
@@ -44,23 +45,57 @@ static const stress_help_t help[] = {
  */
 static int stress_binderfs_supported(const char *name)
 {
+#if defined(__linux__) &&			\
+    defined(HAVE_LINUX_ANDROID_BINDER_H) &&	\
+    defined(HAVE_LINUX_ANDROID_BINDERFS_H)
+	int ret;
+	const char *tmppath = stress_get_temp_path();
+	char path[PATH_MAX];
+
 	if (!stress_check_capability(SHIM_CAP_SYS_ADMIN)) {
 		pr_inf_skip("%s stressor will be skipped, "
 			"need to be running with CAP_SYS_ADMIN "
 			"rights for this stressor\n", name);
 		return -1;
 	}
-	return 0;
+
+	if (!tmppath)
+		return 0;	/* defer */
+
+	if (stress_temp_dir(path, sizeof(path), "binderfs", getpid(), 0) < 0)
+		return 0;	/* defer */
+	if (mkdir(path, S_IRWXU) < 0)
+		return 0;	/* defer */
+	ret = mount("binder", path, "binder", 0, 0);
+	if (ret >= 0) {
+		(void)umount(path);
+		(void)rmdir(path);
+		return 0;
+	}
+
+	if (errno == ENODEV) {
+		pr_inf_skip("%s stressor will be skipped, binderfs not supported\n", name);
+	} else {
+		pr_inf_skip("%s stressor will be skipped, binderfs cannot be mounted\n", name);
+	}
+	/* umount just in case it got mounted and mount way lying */
+	(void)umount(path);
+	(void)rmdir(path);
+	return -1;
+#else
+	pr_inf_skip("%s stressor will be skipped, binderfs not supported\n", name);
+	return -1;
+#endif
 }
 
 #if defined(__linux__) &&			\
     defined(HAVE_LINUX_ANDROID_BINDER_H) &&	\
     defined(HAVE_LINUX_ANDROID_BINDERFS_H)
 
-#define UNMOUNT_TIMEOUT		(5.0)	/* In seconds */
+#define UNMOUNT_TIMEOUT		(15.0)	/* In seconds */
 
 static int stress_binderfs_umount(
-	const stress_args_t *args,
+	stress_args_t *args,
 	const char *pathname,
 	double *umount_duration,
 	double *umount_count)
@@ -91,7 +126,7 @@ static int stress_binderfs_umount(
 				args->name, t2 - t1);
 			return EXIT_FAILURE;
 		}
-		shim_usleep_interruptible(100000);
+		(void)shim_usleep_interruptible(100000);
 	}
 
 	/* Exercise mount on already umounted path */
@@ -107,7 +142,7 @@ static int stress_binderfs_umount(
  *  stress_binderfs()
  *      stress binderfs
  */
-static int stress_binderfs(const stress_args_t *args)
+static int stress_binderfs(stress_args_t *args)
 {
 	int rc, ret;
 	char pathname[PATH_MAX];
@@ -121,6 +156,8 @@ static int stress_binderfs(const stress_args_t *args)
 	if (ret < 0)
 		return stress_exit_status(-ret);
 
+	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
+	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
@@ -144,7 +181,9 @@ static int stress_binderfs(const stress_args_t *args)
 					args->name, errno, strerror(errno));
 				rc = EXIT_NO_RESOURCE;
 				goto clean;
-			} else if ((errno == ENOSPC) || (errno == ENOMEM)) {
+			} else if ((errno == ENOSPC) ||
+				   (errno == ENOMEM) ||
+				   (errno == EPERM)) {
 				/* ..ran out of resources, skip */
 				pr_inf_skip("%s: mount failed on binderfs at %s, errno=%d (%s), skipping stress test\n",
 					args->name, pathname, errno, strerror(errno));
@@ -171,12 +210,20 @@ static int stress_binderfs(const stress_args_t *args)
 		}
 #if defined(BINDER_CTL_ADD)
 		for (i = 0; i < 256; i++) {
-			(void)memset(&device, 0, sizeof(device));
-			(void)snprintf(device.name, sizeof(device.name), "sng-%d\n", i);
+			(void)shim_memset(&device, 0, sizeof(device));
+			(void)snprintf(device.name, sizeof(device.name), "sng-%d", i);
 			ret = ioctl(fd, BINDER_CTL_ADD, &device);
 			if (ret < 0)
 				goto close_control;
 		}
+		for (i = 0; i < 256; i++) {
+			char devpath[PATH_MAX];
+			char devname[32];
+
+			(void)snprintf(devname, sizeof(devname), "sng-%d", i);
+			(void)stress_mk_filename(devpath, sizeof(devpath), pathname, devname);
+			(void)unlink(devpath);
+		}
 close_control:
 #else
 		UNEXPECTED
@@ -186,8 +233,8 @@ close_control:
 		rc = stress_binderfs_umount(args, pathname, &umount_duration, &umount_count);
 		if (rc != EXIT_SUCCESS)
 			break;
-		inc_counter(args);
-	} while (keep_stressing(args));
+		stress_bogo_inc(args);
+	} while (stress_continue(args));
 
 	rc = EXIT_SUCCESS;
 clean:
@@ -196,24 +243,28 @@ clean:
 	(void)stress_temp_dir_rm_args(args);
 
 	rate = (mount_count > 0.0) ? (double)mount_duration / mount_count : 0.0;
-	stress_misc_stats_set(args->misc_stats, 0, "microsecs per mount", rate * 1000000.0);
+	stress_metrics_set(args, 0, "microsecs per mount",
+		rate * STRESS_DBL_MICROSECOND, STRESS_METRIC_HARMONIC_MEAN);
 	rate = (umount_count > 0.0) ? (double)umount_duration / umount_count : 0.0;
-	stress_misc_stats_set(args->misc_stats, 1, "microsecs per umount", rate * 1000000.0);
+	stress_metrics_set(args, 1, "microsecs per umount",
+		rate * STRESS_DBL_MICROSECOND, STRESS_METRIC_HARMONIC_MEAN);
 
 	return rc;
 }
 
-stressor_info_t stress_binderfs_info = {
+const stressor_info_t stress_binderfs_info = {
 	.stressor = stress_binderfs,
 	.supported = stress_binderfs_supported,
-	.class = CLASS_FILESYSTEM | CLASS_OS,
+	.classifier = CLASS_FILESYSTEM | CLASS_OS,
+	.verify = VERIFY_ALWAYS,
 	.help = help
 };
 #else
-stressor_info_t stress_binderfs_info = {
+const stressor_info_t stress_binderfs_info = {
 	.stressor = stress_unimplemented,
 	.supported = stress_binderfs_supported,
-	.class = CLASS_FILESYSTEM | CLASS_OS,
+	.classifier = CLASS_FILESYSTEM | CLASS_OS,
+	.verify = VERIFY_ALWAYS,
 	.help = help,
 	.unimplemented_reason = "built without android linux/android/binder.h or linux/android/binderfs.h"
 };
