@@ -50,7 +50,7 @@ static void *counter_lock;
  *  stress_iomix_rnd_offset()
  *	generate a random offset between 0..max-1
  */
-static off_t stress_iomix_rnd_offset(const off_t max)
+static inline off_t stress_iomix_rnd_offset(const off_t max)
 {
 	return (off_t)stress_mwc64modn((uint64_t)max);
 }
@@ -118,7 +118,7 @@ static void stress_iomix_fsync_min_1Hz(const int fd)
 			(void)shim_fdatasync(fd);
 			break;
 		case 2:
-			(void)sync();
+			shim_sync();
 			break;
 		}
 	}
@@ -561,8 +561,11 @@ static void stress_iomix_rd_wr_mmap(
 				stress_uint8_put(buffer[0]);
 
 				stress_rndbuf(mmaps[i], page_size);
+#if defined(MS_ASYNC) &&	\
+    defined(MS_SYNC)
 				(void)shim_msync(mmaps[i], page_size,
 					stress_mwc1() ? MS_ASYNC : MS_SYNC);
+#endif
 			}
 		}
 		(void)shim_usleep(100000);
@@ -854,21 +857,21 @@ static void stress_iomix_drop_caches(
 	(void)iomix_bytes;
 
 	do {
-		(void)sync();
+		shim_sync();
 		if (stress_system_write("/proc/sys/vm/drop_caches", "1", 1) < 0)
-			(void)pause();
+			(void)shim_pause();
 		(void)sleep(5);
 		if (UNLIKELY(!stress_continue(args)))
 			return;
-		(void)sync();
+		shim_sync();
 		if (stress_system_write("/proc/sys/vm/drop_caches", "2", 1) < 0)
-			(void)pause();
+			(void)shim_pause();
 		(void)sleep(5);
 		if (UNLIKELY(!stress_continue(args)))
 			return;
-		(void)sync();
+		shim_sync();
 		if (stress_system_write("/proc/sys/vm/drop_caches", "3", 1) < 0)
-			(void)pause();
+			(void)shim_pause();
 		(void)sleep(5);
 	} while (stress_bogo_inc_lock(args, counter_lock, true));
 }
@@ -1099,7 +1102,8 @@ static int stress_iomix(stress_args_t *args)
 {
 	int fd, ret;
 	char filename[PATH_MAX];
-	off_t iomix_bytes, iomix_bytes_total = DEFAULT_IOMIX_BYTES;
+	off_t iomix_bytes, iomix_bytes_total;
+	uint64_t iomix_bytes_u64 = DEFAULT_IOMIX_BYTES;
 	const size_t page_size = args->page_size;
 	size_t i;
 	stress_pid_t *s_pids, *s_pids_head = NULL;
@@ -1128,12 +1132,13 @@ static int stress_iomix(stress_args_t *args)
 		goto tidy_s_pids;
 	}
 
-	if (!stress_get_setting("iomix-bytes", &iomix_bytes_total)) {
+	if (!stress_get_setting("iomix-bytes", &iomix_bytes_u64)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
-			iomix_bytes_total = MAXIMIZED_FILE_SIZE;
+			iomix_bytes_u64 = MAXIMIZED_FILE_SIZE;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
-			iomix_bytes_total = MIN_IOMIX_BYTES;
+			iomix_bytes_u64 = MIN_IOMIX_BYTES;
 	}
+	iomix_bytes_total = (off_t)iomix_bytes_u64;
 	iomix_bytes = iomix_bytes_total / args->instances;
 	if (iomix_bytes < (off_t)MIN_IOMIX_BYTES) {
 		iomix_bytes = (off_t)MIN_IOMIX_BYTES;
@@ -1223,7 +1228,7 @@ static int stress_iomix(stress_args_t *args)
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
 
 	do {
-		pause();
+		(void)shim_pause();
 	} while (stress_bogo_inc_lock(args, counter_lock, false));
 
 	ret = EXIT_SUCCESS;
@@ -1243,7 +1248,7 @@ tidy_s_pids:
 }
 
 static const stress_opt_t opts[] = {
-	{ OPT_iomix_bytes, "iomix-bytes", TYPE_ID_OFF_T, MIN_IOMIX_BYTES, MAX_IOMIX_BYTES, NULL },
+	{ OPT_iomix_bytes, "iomix-bytes", TYPE_ID_UINT64_BYTES_FS, MIN_IOMIX_BYTES, MAX_IOMIX_BYTES, NULL },
 	END_OPT,
 };
 
