@@ -20,9 +20,25 @@
 #include "core-builtin.h"
 #include "core-cpu-cache.h"
 #include "core-killpid.h"
+#include "core-mmap.h"
 #include "core-numa.h"
 #include "core-out-of-memory.h"
 
+#define MMAP_MAPPINGS_MAX		(128)
+#define MMAP_SIZE_MAP			(512)	/* in pages */
+
+#define PAGE_WR_FLAG			(0x01)
+#define PAGE_RD_FLAG			(0x02)
+
+#define MIN_MMAPTORTURE_BYTES		(16 * MB)
+#define MAX_MMAPTORTURE_BYTES   	(MAX_MEM_LIMIT)
+#define DEFAULT_MMAPTORTURE_BYTES	(256 * MB)
+
+#define MIN_MMAPTORTURE_MSYNC		(0)
+#define MAX_MMAPTORTURE_MSYNC		(100)
+#define DEFAULT_MMAPTORTURE_MSYNC	(10)
+
+
 static const stress_help_t help[] = {
 	{ NULL,	"mmaptorture N",	"start N workers torturing page mappings" },
 	{ NULL, "mmaptorture-bytes N",	"size of file backed region to be memory mapped" },
@@ -31,27 +47,20 @@ static const stress_help_t help[] = {
 	{ NULL,	NULL,			NULL }
 };
 
+static const stress_opt_t opts[] = {
+        { OPT_mmaptorture_bytes, "mmaptorture-bytes", TYPE_ID_SIZE_T_BYTES_VM, MIN_MMAPTORTURE_BYTES, MAX_MMAPTORTURE_BYTES, NULL },
+	{ OPT_mmaptorture_msync, "mmaptorture-msync", TYPE_ID_UINT32, MIN_MMAPTORTURE_MSYNC, MAX_MMAPTORTURE_MSYNC, NULL },
+	END_OPT
+};
+
+#if defined(HAVE_SIGLONGJMP)
+
 typedef struct {
 	uint8_t *addr;
 	size_t	size;
 	off_t	offset;
 } mmap_info_t;
 
-#define MMAP_MAPPINGS_MAX	(128)
-#define MMAP_SIZE_MAP		(512)	/* in pages */
-
-#define PAGE_WR_FLAG		(0x01)
-#define PAGE_RD_FLAG		(0x02)
-
-
-#define MIN_MMAPTORTURE_BYTES		(16 * MB)
-#define MAX_MMAPTORTURE_BYTES   	(MAX_MEM_LIMIT)
-#define DEFAULT_MMAPTORTURE_BYTES	(256 * MB)
-
-#define MIN_MMAPTORTURE_MSYNC		(0)
-#define MAX_MMAPTORTURE_MSYNC		(100)
-#define DEFAULT_MMAPTORTURE_MSYNC	(10)
-
 typedef struct {
 	uint64_t	mmap_pages;
 	uint64_t	sync_pages;
@@ -330,6 +339,7 @@ static void NORETURN MLOCKED_TEXT stress_mmaptorture_sighandler(int signum)
 		break;
 	}
 	siglongjmp(jmp_env, 1);	/* Ugly, bounce back */
+	stress_no_return();
 }
 
 static void stress_mmaptorture_msync(
@@ -372,7 +382,7 @@ static void stress_mmaptorture_vm_name(
 {
 	char vma_name[32];
 	size_t i, j;
-	char hex[] = "0123456789ABCDEF";
+	static const char hex[] = "0123456789ABCDEF";
 
 	for (i = 0, j = 0; i < size; i += page_size, j++) {
 		(void)stress_rndstr(vma_name, sizeof(vma_name));
@@ -422,13 +432,16 @@ static int stress_mmaptorture_child(stress_args_t *args, void *context)
 
 	data = malloc(page_size);
 	if (UNLIKELY(!data)) {
-		pr_fail("%s: malloc failed, out of memory\n", args->name);
+		pr_fail("%s: malloc of %zu bytes failed%s, out of memory\n",
+			args->name, page_size, stress_get_memfree_str());
 		return EXIT_NO_RESOURCE;
 	}
 
 	mappings = (mmap_info_t *)calloc((size_t)MMAP_MAPPINGS_MAX, sizeof(*mappings));
 	if (UNLIKELY(!mappings)) {
-		pr_fail("%s: calloc failed, out of memory\n", args->name);
+		pr_fail("%s: calloc of %zu bytes failed%s, out of memory\n",
+			args->name, (size_t)MMAP_MAPPINGS_MAX * sizeof(*mappings),
+			stress_get_memfree_str());
 		free(data);
 		return EXIT_NO_RESOURCE;
 	}
@@ -547,7 +560,7 @@ retry:
 				int shm_fd;
 				char shm_name[128];
 
-				(void)snprintf(shm_name, sizeof(shm_name), "%s-%" PRIdMAX "-%zd",
+				(void)snprintf(shm_name, sizeof(shm_name), "%s-%" PRIdMAX "-%zu",
 						args->name, (intmax_t)mypid, n);
 				shm_fd = shm_open(shm_name, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR);
 				if (shm_fd < 0)
@@ -596,7 +609,7 @@ mapped_ok:
 			}
 #if defined(HAVE_LINUX_MEMPOLICY_H)
 			if (numa_mask && numa_nodes && stress_mwc1())
-				stress_numa_randomize_pages(args, numa_nodes, numa_mask, (void *)ptr, page_size, mmap_size);
+				stress_numa_randomize_pages(args, numa_nodes, numa_mask, (void *)ptr, mmap_size, page_size);
 
 #if defined(HAVE_MSYNC) &&	\
     defined(MS_SYNC) &&		\
@@ -664,7 +677,7 @@ mapped_ok:
 			if (stress_mwc1()) {
 				int ret;
 
-				ret = stress_munmap_retry_enomem((void *)ptr, mmap_size);
+				ret = stress_munmap_force((void *)ptr, mmap_size);
 				if (ret == 0) {
 #if defined(MAP_FIXED)
 					if (stress_mwc1()) {
@@ -714,7 +727,7 @@ mapped_ok:
 
 					if (stress_mwc1()) {
 						if ((ptr != MAP_FAILED) && (mmap_size > 0)) {
-							(void)stress_munmap_retry_enomem((void *)(ptr + i), page_size);
+							(void)stress_munmap_force((void *)(ptr + i), page_size);
 							mappings[i].addr = MAP_FAILED;
 							mappings[i].size = 0;
 						}
@@ -737,7 +750,7 @@ mapped_ok:
 					mmap_size = mappings[i].size;
 
 					if ((ptr != MAP_FAILED) && (mmap_size > 0)) {
-						(void)stress_munmap_retry_enomem((void *)ptr, mmap_size);
+						(void)stress_munmap_force((void *)ptr, mmap_size);
 						mappings[i].addr = MAP_FAILED;
 						mappings[i].size = 0;
 					}
@@ -797,7 +810,7 @@ mappings_unmap:
 								mmap_stats->madvise_pages += 1;
 #endif
 						}
-						(void)stress_munmap_retry_enomem((void *)(ptr + j), page_size);
+						(void)stress_munmap_force((void *)(ptr + j), page_size);
 					}
 				}
 #endif
@@ -858,19 +871,16 @@ static int stress_mmaptorture(stress_args_t *args)
 					PROT_READ | PROT_WRITE,
 					MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (mmap_stats == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap stats shared page, skipping stressor\n", args->name);
+		pr_inf_skip("%s: cannot mmap %zu bytes stats shared page%s, "
+			"errno=%d (%s), skipping stressor\n", args->name,
+			sizeof(*mmap_stats), stress_get_memfree_str(),
+			errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
 
-	if (args->instance == 0) {
-		char str1[64], str2[64];
+	if (stress_instance_zero(args))
+		stress_usage_bytes(args, mmap_bytes, mmap_bytes * args->instances);
 
-		stress_uint64_to_str(str1, sizeof(str1), (uint64_t)mmap_bytes, 1, true);
-		stress_uint64_to_str(str2, sizeof(str2), (uint64_t)mmap_bytes * args->instances, 1, true);
-
-		pr_inf("%s: using %smmap'd size %s per stressor (total %s)\n", args->name,
-			mmap_bytes_adjusted ? "adjusted " : "", str1, str2);
-	}
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
 	stress_sync_start_wait(args);
 	stress_set_proc_state(args->name, STRESS_STATE_RUN);
@@ -903,18 +913,25 @@ static int stress_mmaptorture(stress_args_t *args)
 	return ret;
 }
 
-static const stress_opt_t opts[] = {
-        { OPT_mmaptorture_bytes, "mmaptorture-bytes", TYPE_ID_SIZE_T_BYTES_VM, MIN_MMAPTORTURE_BYTES, MAX_MMAPTORTURE_BYTES, NULL },
-	{ OPT_mmaptorture_msync, "mmaptorture-msync", TYPE_ID_UINT32, MIN_MMAPTORTURE_MSYNC, MAX_MMAPTORTURE_MSYNC, NULL },
-	END_OPT
-};
-
 const stressor_info_t stress_mmaptorture_info = {
 	.stressor = stress_mmaptorture,
-	.class = CLASS_VM | CLASS_OS,
+	.classifier = CLASS_VM | CLASS_OS,
 	.verify = VERIFY_NONE,
 	.init = stress_mmaptorture_init,
 	.deinit = stress_mmaptorture_deinit,
 	.opts = opts,
 	.help = help
 };
+
+#else
+
+const stressor_info_t stress_mmaptorture_info = {
+	.stressor = stress_unimplemented,
+	.classifier = CLASS_VM | CLASS_OS,
+	.verify = VERIFY_NONE,
+	.opts = opts,
+	.help = help,
+	.unimplemented_reason = "built without siglongjmp support",
+};
+
+#endif
