@@ -576,7 +576,8 @@ static int stress_sem_sysv(stress_args_t *args)
 
 	s_pids = stress_sync_s_pids_mmap(MAX_SEM_SYSV_PROCS);
 	if (s_pids == MAP_FAILED) {
-		pr_inf_skip("%s: failed to mmap %d PIDs, skipping stressor\n", args->name, MAX_SEM_SYSV_PROCS);
+		pr_inf_skip("%s: failed to mmap %d PIDs%s, skipping stressor\n",
+			args->name, MAX_SEM_SYSV_PROCS, stress_get_memfree_str());
 		return EXIT_NO_RESOURCE;
 	}
 
@@ -596,7 +597,7 @@ static int stress_sem_sysv(stress_args_t *args)
 
 	/* Wait for termination */
 	while (stress_continue(args))
-		pause();
+		(void)shim_pause();
 reap:
 	stress_set_proc_state(args->name, STRESS_STATE_DEINIT);
 	stress_kill_and_wait_many(args, s_pids, semaphore_sysv_procs, SIGALRM, true);
@@ -609,7 +610,7 @@ const stressor_info_t stress_sem_sysv_info = {
 	.stressor = stress_sem_sysv,
 	.init = stress_semaphore_sysv_init,
 	.deinit = stress_semaphore_sysv_deinit,
-	.class = CLASS_OS | CLASS_SCHEDULER | CLASS_IPC,
+	.classifier = CLASS_OS | CLASS_SCHEDULER | CLASS_IPC,
 	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help
@@ -617,7 +618,7 @@ const stressor_info_t stress_sem_sysv_info = {
 #else
 const stressor_info_t stress_sem_sysv_info = {
 	.stressor = stress_unimplemented,
-	.class = CLASS_OS | CLASS_SCHEDULER | CLASS_IPC,
+	.classifier = CLASS_OS | CLASS_SCHEDULER | CLASS_IPC,
 	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help,
