@@ -189,8 +189,9 @@ static int stress_shm_posix_child(
 			}
 			if (UNLIKELY(addr == MAP_FAILED)) {
 				ok = false;
-				pr_fail("%s: mmap failed, errno=%d (%s)\n",
-					args->name, errno, strerror(errno));
+				pr_fail("%s: failed to mmap %zu bytes%s, errno=%d (%s)\n",
+					args->name, sz, stress_get_memfree_str(),
+					errno, strerror(errno));
 				rc = EXIT_FAILURE;
 				(void)close(shm_fd);
 				goto reap;
@@ -224,7 +225,7 @@ static int stress_shm_posix_child(
 			/* Expand the mapping */
 			(void)shim_fallocate(shm_fd, 0, 0, (off_t)(sz + page_size));
 
-			(void)stress_madvise_random(addr, sz);
+			(void)stress_madvise_randomize(addr, sz);
 			(void)shim_msync(addr, sz, stress_mwc1() ? MS_ASYNC : MS_SYNC);
 			(void)shim_fsync(shm_fd);
 			VOID_RET(off_t, lseek(shm_fd, (off_t)0, SEEK_SET));
@@ -356,7 +357,7 @@ static int stress_shm(stress_args_t *args)
 	bool retry = true;
 	bool shm_mlock = false;
 	uint32_t restarts = 0;
-	size_t shm_posix_bytes = DEFAULT_SHM_POSIX_BYTES;
+	size_t shm_posix_bytes, shm_posix_bytes_total = DEFAULT_SHM_POSIX_BYTES;
 	size_t shm_posix_objects = DEFAULT_SHM_POSIX_OBJECTS;
 
 	if (!stress_get_setting("shm-mlock", &shm_mlock)) {
@@ -364,17 +365,19 @@ static int stress_shm(stress_args_t *args)
 			shm_mlock = true;
 	}
 
-	if (!stress_get_setting("shm-bytes", &shm_posix_bytes)) {
+	if (!stress_get_setting("shm-bytes", &shm_posix_bytes_total)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
-			shm_posix_bytes = MAX_SHM_POSIX_BYTES;
+			shm_posix_bytes_total = MAX_SHM_POSIX_BYTES;
 		if (g_opt_flags & OPT_FLAGS_MINIMIZE)
-			shm_posix_bytes = MIN_SHM_POSIX_BYTES;
+			shm_posix_bytes_total = MIN_SHM_POSIX_BYTES;
 	}
-	shm_posix_bytes /= args->instances;
+	shm_posix_bytes = shm_posix_bytes_total / args->instances;
 	if (shm_posix_bytes < MIN_SHM_POSIX_BYTES)
 		shm_posix_bytes = MIN_SHM_POSIX_BYTES;
 	if (shm_posix_bytes < page_size)
 		shm_posix_bytes = page_size;
+	if (stress_instance_zero(args))
+		stress_usage_bytes(args, shm_posix_bytes, shm_posix_bytes * args->instances);
 
 	if (!stress_get_setting("shm-objs", &shm_posix_objects)) {
 		if (g_opt_flags & OPT_FLAGS_MAXIMIZE)
@@ -430,7 +433,9 @@ again:
 
 			shm_names = (char *)calloc(shm_posix_objects, SHM_NAME_LEN);
 			if (!shm_names) {
-				pr_fail("%s: calloc failed, out of memory\n", args->name);
+				pr_fail("%s: failed to allocate %zu bytes%s, out of memory\n",
+					args->name, shm_posix_objects * SHM_NAME_LEN,
+					stress_get_memfree_str());
 				(void)close(pipefds[0]);
 				(void)close(pipefds[1]);
 				rc = EXIT_NO_RESOURCE;
@@ -523,7 +528,7 @@ err:
 
 const stressor_info_t stress_shm_info = {
 	.stressor = stress_shm,
-	.class = CLASS_VM | CLASS_OS | CLASS_IPC,
+	.classifier = CLASS_VM | CLASS_OS | CLASS_IPC,
 	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help
@@ -531,7 +536,7 @@ const stressor_info_t stress_shm_info = {
 #else
 const stressor_info_t stress_shm_info = {
 	.stressor = stress_unimplemented,
-	.class = CLASS_VM | CLASS_OS | CLASS_IPC,
+	.classifier = CLASS_VM | CLASS_OS | CLASS_IPC,
 	.opts = opts,
 	.verify = VERIFY_ALWAYS,
 	.help = help,
